summaryrefslogtreecommitdiffstats
path: root/bin
diff options
context:
space:
mode:
Diffstat (limited to 'bin')
-rwxr-xr-xbin/updater/owncloud_news_updater/application.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/updater/owncloud_news_updater/application.py b/bin/updater/owncloud_news_updater/application.py
index beedba1b4..b6d166b03 100755
--- a/bin/updater/owncloud_news_updater/application.py
+++ b/bin/updater/owncloud_news_updater/application.py
@@ -33,9 +33,9 @@ def main():
type=int)
parser.add_argument('--interval', '-i',
help='Update interval between fetching the next round of \
updates in minutes, defaults to 30 minutes. The update timespan \
will be subtracted from the interval.',
- default=30,
+ default=15*60,
type=int)
parser.add_argument('--config', '-c',
help='Path to config file where all parameters except can be defined \
@@ -33,9 +33,9 @@ def main():
parser.add_argument('--interval', '-i',
help='Update interval between fetching the next round of \
- updates in minutes, defaults to 30 minutes. The update timespan \
+ updates in seconds, defaults to 15 minutes. The update timespan \
will be subtracted from the interval.',